#
# spec file for package libtool
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


###################################################################
# NOTE: PLease run pre_checkin.sh before checking in the package! #
###################################################################

Name:           libtool
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  gcc-objc
BuildRequires:  lzma
BuildRequires:  makeinfo
BuildRequires:  zlib-devel
Requires:       automake > 1.4
Requires:       tar
Summary:        A Tool to Build Shared Libraries
License:        GPL-2.0+ and LGPL-2.1+ and GFDL-1.2+
Group:          Development/Tools/Building
Version:        2.4.2
Release:        18.101
# bug437293
%ifarch ppc64
Obsoletes:      libtool-64bit
%endif
#
PreReq:         %{install_info_prereq}
Requires:       libltdl7 = %{version}
Url:            http://www.gnu.org/software/libtool/
Source:         http://ftp.gnu.org/gnu/libtool/libtool-%{version}.tar.gz
Source2:        baselibs.conf
Source3:        libtool-rpmlintrc
#Patch:          libtool-%%{version}.diff
Patch1:         config-guess-sub-update.patch
Patch2:         libtool-ppc64le.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Provides:       libltdl-devel
# fedora name
Provides:       libtool-ltdl-devel

%description
GNU libtool is a set of shell scripts to automatically configure UNIX
architectures to build shared libraries in a generic fashion.

%package -n libltdl7
Summary:        Libtool Runtime Library
License:        LGPL-2.1+
Group:          Development/Libraries/C and C++

%description -n libltdl7
Library needed by programs that use the ltdl interface of GNU libtool.

%prep
%setup -q -n libtool-%{version}
%patch1
%patch2 -p1

%build
./configure CFLAGS="$RPM_OPT_FLAGS" \
   --prefix=/usr --infodir=%{_infodir} --libdir=%{_libdir}
# force rebuild with non-broken makeinfo
rm -f doc/libtool.info
make %{?_smp_mflags}

%if "%{name}" == "libtool-testsuite"

%check
trap 'test $? -ne 0 && cat tests/testsuite.log' EXIT
# Avoid spurious testsuite failures due to messages from icecream
PATH=/usr/bin:$PATH
make check

%install
%else

%install
make install DESTDIR=$RPM_BUILD_ROOT
%endif

%post
%install_info --info-dir=%{_infodir} %{_infodir}/libtool.info.gz

%postun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/libtool.info.gz

%post -n libltdl7 -p /sbin/ldconfig

%postun -n libltdl7 -p /sbin/ldconfig

%clean
rm -rf $RPM_BUILD_ROOT

%if "%{name}" == "libtool"

%files
%defattr(-, root, root)
%doc AUTHORS NEWS README THANKS ChangeLog COPYING
/usr/bin/libtool
/usr/bin/libtoolize
/usr/include/libltdl
/usr/include/ltdl.h
%{_libdir}/libltdl.a
%attr(644, root, root) %{_libdir}/libltdl.la
%{_libdir}/libltdl.so
/usr/share/aclocal/*.m4
%doc %{_infodir}/libtool.info*
%doc %{_mandir}/man1/libtool.1.gz
%doc %{_mandir}/man1/libtoolize.1.gz
/usr/share/libtool

%files -n libltdl7
%defattr(-, root, root)
%{_libdir}/libltdl.so.*
%endif

%changelog
* Tue Sep  9 2014 coolo@suse.com
- install COPYING as %%doc
* Mon Jul 14 2014 dvaleev@suse.com
- Add libtool-ppc64le.patch to fix libtool-testsuite tests
* Tue Nov 26 2013 pth@suse.de
- Change License as described in bnc#818958.
* Sat Feb  2 2013 schwab@suse.de
- Add config-guess-sub-update.patch:
  Update config.guess/sub for aarch64
* Thu Jul 19 2012 pth@suse.de
- buildrequire makeinfo which is a seperate package now.
* Tue Nov 29 2011 coolo@suse.com
- buildrequire automake for file list check
* Thu Nov 10 2011 dmueller@suse.de
- update to 2.4.2:
  - The generic approximation of the command line length limit (when getconf is
    not available) works again.  Regression introduced in v2.2.6-39-g9c3d4d8.
  - The bug that leaked developer tool paths into the release tarballs
    from ./bootstrap is fixed.
  - Improved support for the Cuda Compiler Driver (nvcc) on Darwin.
  - For GCC LTO support, the -fuse-linker-plugin switch is now also removed
    when computing compiler postdeps.
  - The undocumented hardcode_libdir_flag_spec_ld tag variable has been
    removed in favor of using hardcode_libdir_flag_spec with $wl set to empty.
* Fri Sep 16 2011 coolo@suse.com
- don't use _service
* Fri Jul 29 2011 pth@suse.de
- Add gcc-c++ gcc-fortran and gcc-objc to buildrequires so that
  packages using the system wide libtool script compile.
- Add a rpmlintrc to shut up rpmlint on most warnings.
* Mon Mar 14 2011 coolo@novell.com
- require automake and provide symbolic names for libltdl
* Wed Mar  9 2011 giecrilj@stegny.2a.pl
- update to 2.4, which has quite some new stuff. Limiting here to
  incompatible changes:
  - The fix_srcfile_path variable has been replaced by a more thorough
    mechanism triggered by the to_tool_file_cmd variable.
  - The wrapper command line option support described above introduces the
    following incompatibility: the wrapper will remove any command line
    options that begin with '--lt-*' from the argument list before launching
    (uninstalled) programs. Any '--lt-*' option on the command line not
    recognized by the wrapper will result in an error.
  - The type of the symbol lists variables (lt_*_LTX_preloaded_symbols) has
    been fixed in the manual and in a couple of tests to match the actual
    implementation.
* Mon Feb 28 2011 jslaby@suse.de
- Fix AC_LANG_PROGRAM warnings (bnc#675573)
* Sun Oct 31 2010 jengelh@medozas.de
- Use %%_smp_mflags
* Mon May 31 2010 coolo@novell.com
- add an empty install section
* Thu May 27 2010 coolo@novell.com
- split out the test suite that takes 95%% of the build time
* Thu May 27 2010 dmueller@suse.de
- tar is in /bin/tar, so a requires to /usr/bin/tar doesn't work
* Fri May  7 2010 pth@novell.com
- Libtool needs tar so add it as Requires (bnc#526298).
* Sun Dec 13 2009 jengelh@medozas.de
- add baselibs.conf as source2
* Sat Dec 12 2009 aj@suse.de
- Add libtool-no-hostname.patch to not write hostname in libtool
  to avoid rebuilds where nothing has changed beside the build host.
* Wed Nov 18 2009 pth@suse.de
- VUL-0 CVE-2009-3736 Update to 2.2.6b (bnc#556122):
  * Fix libltdl to no longer attempt to dlopen() the old_library
    listed in the .la file. Now will use only the preopen loader to
    attempt to load it. This may be a security issue, all users are
    advised to upgrade.
  * Similarly, don't open module.la from the current directory, this
    changes the behavior of libltdl to match the documentation.
  * Adapt test suite to changes.
* Sat Feb  7 2009 schwab@suse.de
- Rebuild broken info file.
* Fri Jan  9 2009 schwab@suse.de
- Fix last change.
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Sun Sep  7 2008 schwab@suse.de
- Update to libtool 2.2.6.
  * New features:
  - New lt_dloadvise_preload() call to set a hint that only preloadeded
    modules can be opened.
  - libtoolize no longer removes config.guess and config.sub, even when
  - -install is passed.
  * Changes in supported systems or compilers:
  - Fixes for ifort on Darwin, and newer Intel compilers (icc 10, ifort 9)
    on GNU/Linux.
  - Fixes for cwrapper (cygwin/mingw) under -stdc=c99.
  - Support cross compile of MinGW with Wine.
  - Initial support for cegcc (Windows CE/PocketPC) cross compilation.
  - Initial support for lf95 (Lahey Fortran 8.1) on GNU/Linux.
  * Bug fixes:
  - Several testsuite issues have been fixed, thanks to user feedback.
  - Fix 2.2 regression that caused argz symbols to be exported from
    libltdl unrenamed on systems that do not have working argz.
  - Revert "lt_dlopen(NULL) works on AIX again.". It was not the
    correct fix.
  - Diagnose '-L' arguments correctly.
  - Libtool no longer tries to open devices as files in execute mode.
  - Libtool no longer removes *.gcno profile information from GCC.
* Wed May 21 2008 cthiel@suse.de
- fix baselibs.conf
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Fri Feb  1 2008 schwab@suse.de
- Update to libtool 1.5.26.
  * Improved support for Mac OS X Leopard.
  * More robust parsing of mangled `.la' files inside libltdl, fixing a
    possible overrun and a crash due to memory exhaustion.
  * Fix compile command line for gcj on MinGW.
  * Some configure variables have been renamed to fix caching:
    lt_prog_compiler_pic_works to lt_cv_prog_compiler_pic_works
    lt_prog_compiler_static_works to lt_cv_prog_compiler_static_works.
  * Support for AIX 6.1.
  * Bug Fixes.
* Tue Nov 13 2007 schwab@suse.de
- Fix C++ includes.
* Wed Jun 27 2007 schwab@suse.de
- Update to libtool 1.5.24.
  * Initial support for Interix newer than version 3.
  * Use getconf ARG_MAX to find the max command line length.
  * Bug Fixes.
* Wed Jun  6 2007 schwab@suse.de
- Rename libltdl to libltdl-3.
* Mon Sep 18 2006 schwab@suse.de
- Remove build requires.
* Tue May 23 2006 schwab@suse.de
- Fix dependency.
* Fri Jan 27 2006 schwab@suse.de
- Split off libtldl package.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 13 2006 schwab@suse.de
- Run ldconfig.
* Mon Jan  9 2006 schwab@suse.de
- Update to libtool 1.5.22.
* Thu Sep  1 2005 schwab@suse.de
- Update to libtool 1.5.20.
* Tue May 17 2005 schwab@suse.de
- Update to libtool 1.5.18.
* Thu Apr 28 2005 schwab@suse.de
- Don't install in libltdl data files in libltdl directory.
* Tue Apr 26 2005 schwab@suse.de
- Update to libtool 1.5.16.
* Sat Feb 12 2005 schwab@suse.de
- Update to libtool 1.5.14.
* Mon Feb  7 2005 schwab@suse.de
- Fix handling of -pthread during linking.
* Sat Feb  5 2005 schwab@suse.de
- Update to libtool 1.5.12.
* Fri Oct  8 2004 schwab@suse.de
- Update to libtool 1.5.10.
* Tue Aug 10 2004 ro@suse.de
- clean neededforbuild
* Sat Aug  7 2004 schwab@suse.de
- Update to libtool 1.5.8.
* Mon Apr 12 2004 schwab@suse.de
- Update to libtool 1.5.6.
* Mon Jan 26 2004 schwab@suse.de
- Update to libtool 1.5.2.
* Wed Oct 15 2003 schwab@suse.de
- Make sure we get a full-featured libtool [#32356].
* Thu Jul  3 2003 meissner@suse.de
- biarch fix for powerpc64-*linux*.
* Fri Apr 25 2003 schwab@suse.de
- Update to libtool 1.5.
- Fix AC_PROG_LD_GNU.
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Mon Apr  7 2003 schwab@suse.de
- Only delete info entries when removing last version.
* Thu Feb  6 2003 schwab@suse.de
- Use %%install_info.
* Wed Dec  4 2002 schwab@suse.de
- Make sure we are using the fixed libtool macros during configuring.
* Thu Oct 24 2002 schwab@suse.de
- Update to libtool 1.4.3.
* Thu Sep 19 2002 schwab@suse.de
- Remove execute permission from *.la.
- libtoolize: fix reference to configure.in.
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Mon Jul 29 2002 meissner@suse.de
- Added patch for a directory open problem (exhibited by gphoto in
  LANG=de_DE). (extracted from libtool CVS)
* Fri Jun  7 2002 schwab@suse.de
- Fix for lib64.
* Wed Jun  5 2002 schwab@suse.de
- Fix logic in ltmain.sh.
* Mon Apr 15 2002 sf@suse.de
- use pass_all in AC_DEPLIBS_CHECK_METHOD for x86_64
* Thu Mar 28 2002 schwab@suse.de
- Fix last change to not patch the generated file.
* Wed Feb 13 2002 stepan@suse.de
- allow link against an archive when building a shared library
- patch to use mktemp to create the tempdir
- fix test quoting in ltmain.in
* Tue Feb  5 2002 schwab@suse.de
- Add patch to support DESTDIR.
* Fri Jan  4 2002 schwab@suse.de
- Quote $AS when writing it to libtool script.
* Tue Nov 13 2001 schwab@suse.de
- Use pass_all on mips.
* Mon Oct  8 2001 schwab@suse.de
- Fix quoting with "libtool --mode=execute".
* Thu Sep 27 2001 schwab@suse.de
- Update to libtool 1.4.2 (more portability fixes).
* Tue Sep  4 2001 schwab@suse.de
- Update to libtool 1.4.1 (only portability fixes).
* Mon Jul 23 2001 schwab@suse.de
- Use pass_all in AC_DEPLIBS_CHECK_METHOD for s390* and m68k.
* Tue Jun 12 2001 schwab@suse.de
- Add URL.
- Install some docs.
* Mon Jun 11 2001 olh@suse.de
- recognize ppc64
* Thu May  3 2001 schwab@suse.de
- Update to libtool 1.4.
* Mon Feb 19 2001 schwab@suse.de
- Fix use of suse_update_config macro.
* Mon Feb 19 2001 ro@suse.de
- fix specfile for sparc64  (again)
* Thu Feb 15 2001 fober@suse.de
- add suse_update_config (for the reason of 390 and the sake of the
  rest)
* Wed Sep 20 2000 fober@suse.de
- s390: change deplibs_check_method back to file_magic (like 1.3.4)
* Mon Sep  4 2000 nadvornik@suse.cz
- update to 1.3.5
* Fri May 12 2000 schwab@suse.de
- Don't add libc to deplibs on Linux.
* Sat Apr  1 2000 bk@suse.de
- updated config.sub and config.guess patches for s390
* Tue Mar 28 2000 bk@suse.de
- patched config.sub and config.guess for s390
* Wed Mar 22 2000 schwab@suse.de
- Fix linux -> linux-gnu transformation in ltconfig.
* Fri Feb 11 2000 kukuk@suse.de
- Add patches from LinuxPPC reference sources
* Tue Jan 25 2000 kukuk@suse.de
- Update to 1.3.4
- move /usr/info -> /usr/share/info
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon Jul 19 1999 florian@suse.de
- update to version 1.3.3
* Sat Sep 26 1998 ke@suse.de
- initial version: 1.2b.
